********************************************
*  "Widening Political Inequality in Japan 
*   during the 'Lost Two-Decades'”
*  STATA do file
*
*  (c)2018 by Yoshitaka Nishizawa
********************************************.


cd "/Users/ynishiza2017/Desktop/DLR1803_Inequality_Nishizawa"

/* ssc install coefplot, replace */

use "jes2thu4-forVoteModelwithLimitedIVs.dta" , clear
gen m9610=m9307 - 39
tab m9610
gen y9610=m9610/12
tab y9610

/* dummies for inc361  */
gen bot30=inc361
recode bot30 (1=1)(2 3=0)
tab bot30 inc361
gen mid60=inc361
recode mid60 (2=1)(1 3=0)
tab mid60 inc361
gen top10=inc361
recode top10 (3=1)(1 2=0)
tab top10 inc361

/*********************/
/* Fig 3: DV=vpr4 */
/*********************/
set more off
mlogit vpr4 welfAB libcon lif1 class5 efc1 efc4 ///
       tmLDP tmDPJ female age educ income y9610
estimates store x1
coefplot x1, drop(_cons) xline(0) 

/*********************/
/* Footnote 16: Cheking for interaction effect of welfAB and income */
/*********************/
gen welfAB_income=welfAB * income
set more off
mlogit vpr4 welfAB libcon lif1 class5 efc1 efc4 ///
       tmLDP tmDPJ female age educ income welfAB_income y9610
estimates store x2
coefplot x2, drop(_cons) xline(0) 

/*********************/
/* Fig 4: Vote Pro. by income */
/*********************/
set more off
mlogit vpr4 welfAB libcon lif1 class5 efc1 efc4 ///
       tmLDP tmDPJ female age educ income y9610
predict ldp, o(1)
predict dpj, o(2)
predict oth, o(3)

graph twoway ///
  (lfitci ldp income, lcolor(black) bcolor(bluishgray)) /// 
  (lfitci dpj income, lpattern(dash) lcolor(black) bcolor(bluishgray))  ///
  (lfitci oth income, lpattern(shortdash) lcolor(black) bcolor(bluishgray)), ///
  ytitle("Prob voting") ///
  ylabel(0(.2)1, grid) ///
  xtitle(income)  ///
  xlabel(0(500)3000) ///
  legend(order (2 "For LDP" 4 "For DPJ" 6 "for Other") cols(1) )
	   
/*****************/
/*  Fig 5: weflAB as DV  */
/*****************/
reg welfAB libcon lif1  class5 efc1  efc4 ///
       tmLDP tmDPJ female age educ income y9610
coefplot, drop(_cons) xline(0)

/*****************/
/*  Footnote 17: Checking for non-linear effect of income  */
/*****************/
gen income2=income*income
set more off
reg welfAB libcon lif1  class5 efc1  efc4 ///
       tmLDP tmDPJ female age educ income income2 y9610
coefplot, drop(_cons) xline(0)

gen Log_income=log(income)
set more off
reg welfAB libcon lif1  class5 efc1  efc4 ///
       tmLDP tmDPJ female age educ Log_income y9610
coefplot, drop(_cons) xline(0)

/*****************/
/*  Footnote 18: Model with elelction year dummies  */
/*****************/
tab m9610
gen shu96=0
replace shu96=1 if m9610==1
tab shu96
gen shu03=0
replace shu03=1 if m9610==85
tab shu03
gen san04=0
replace san04=1 if m9610==94
tab san04
gen shu05=0
replace shu05=1 if m9610==108
tab shu05
gen san07=0
replace san07=1 if m9610==131
tab san07
gen shu09=0
replace shu09=1 if m9610==155
tab shu09
gen san10=0
replace san10=1 if m9610==165
tab san10

set more off
mlogit vpr4 welfAB libcon lif1 class5 efc1 efc4 ///
       tmLDP tmDPJ female age educ income                      ///
	   shu03 san04 shu05 san07 shu09 san10
estimates store x3
coefplot x3, drop(_cons) xline(0) 

/*  End of File  */


